controls

Function controls 

pub fn controls(
    support: &GenerationSupport,
    backend: &BackendCapability,
) -> GenerationControls
Settings that can take effect on this backend for this model. Callers must not infer controls from catalog fields alone.