pub fn controls(
support: &GenerationSupport,
backend: &BackendCapability,
) -> GenerationControlsExpand description
Settings that can take effect on this backend for this model. Callers must not infer controls from catalog fields alone.
pub fn controls(
support: &GenerationSupport,
backend: &BackendCapability,
) -> GenerationControlsSettings that can take effect on this backend for this model. Callers must not infer controls from catalog fields alone.